@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2021, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <sstream>
@@ -213,19 +213,19 @@ int WorkbenchImpl::isOsSupported(const std::string &os) {
   }
 
   static std::vector<std::string> supportedOsList {
-    "Ubuntu 19.10", "Ubuntu 18.04", "Debian 10",
+    "Ubuntu 20.04", "Ubuntu 21.10", "Debian 10",
 
     "Red Hat Enterprise Linux Server release 7", // Oracle 7.1 looks like this: "Red Hat Enterprise Linux Server release
                                                  // 7.1 (Maipo)"
     "Red Hat Enterprise Linux release 8",        // Oracle 8.0: Red Hat Enterprise Linux release 8.0 (Ootpa)
-    "Fedora release 30", "Fedora release 31", "CentOS release 7",
+    "Fedora release 34", "Fedora release 35", "CentOS release 7",
 
     "Windows 10", "Windows Server 2016", "Windows Server 2019",
 
-    "macOS 10.14", "macOS 10.15"
+    "macOS 11", "macOS 12"
   };
 
-  for (std::string s : supportedOsList) {
+  for (std::string s : supportedOsList) { 
     if (os.find(s) != std::string::npos) {
       logDebug2("OS '%s' is supported\n", os.c_str());
       return true;
