@@ -1,20 +1,24 @@
-/* 
- * Copyright (c) 2009, 2015, Oracle and/or its affiliates. All rights reserved.
+/*
+ * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
+ *
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #import "MFContainerBase.h"
@@ -78,7 +82,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
 
 - (void)setEnabled:(BOOL)flag
 {
-  for (id subview in [self subviews])
+  for (id subview in self.subviews)
   {
     if ([subview respondsToSelector: @selector(setEnabled:)])
       [subview setEnabled: flag];
@@ -87,33 +91,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
 
 //--------------------------------------------------------------------------------------------------
 
-- (void)subviewMinimumSizeChanged
-{
-  NSSize minSize= [self preferredSize];
-  NSSize size= [self frame].size;
-  
-  // size of some subview has changed, we check if our current size is enough
-  // to fit it and if not, request forward the size change notification to superview
-  
-  if (mFreezeRelayout > 0)
-    return;
-
-  if (minSize.width != size.width || minSize.height != size.height)
-  {
-    if ([self superview])
-    {
-      [[self superview] subviewMinimumSizeChanged];
-      return;
-    }
-    else
-      [self setFrameSize: minSize];
-  }
-  [self resizeSubviewsWithOldSize:size];
-}
-
-//--------------------------------------------------------------------------------------------------
-
-- (BOOL)setFreezeRelayout:(BOOL)flag
+- (BOOL)setFreezeRelayout: (BOOL)flag
 {
   if (flag)
     mFreezeRelayout++;
@@ -124,11 +102,10 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
     {
       // exec when idle to avoid crashes caused by unsettled structure changes
       // (like when removing subviews from a container destructor)
-      [self performSelector: @selector(subviewMinimumSizeChanged)
+      [self performSelector: @selector(relayout)
                  withObject: nil
                  afterDelay: 0
                     inModes: @[NSModalPanelRunLoopMode, NSDefaultRunLoopMode]];
-      [[self window] recalculateKeyViewLoop];
       return YES;
     }
   }
@@ -164,13 +141,13 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
   }
   else if (mDefaultBackColor != nil)
   {
-    id parent = [self superview];
+    id parent = self.superview;
     // check if we're inside a NSBox or NSTabView, which draw their own background
     while (parent)
     {
       // TODO: move MFTabViewImpl to mforms dylib and use normal class access instead objc_getClass.
       if ([parent isKindOfClass: [NSBox class]] || ([parent isKindOfClass: objc_getClass("MFTabViewImpl")] && 
-                                                    [[parent tabView] tabViewType] != NSNoTabsNoBorder))
+                                                    [parent tabView].tabViewType != NSNoTabsNoBorder))
         break;
       parent = [parent superview];
     }
@@ -184,8 +161,8 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
   if (mBackImage)
   {
     float x, y;
-    NSSize isize = [mBackImage size];
-    NSSize fsize = [self frame].size;
+    NSSize isize = mBackImage.size;
+    NSSize fsize = self.frame.size;
 
     if (fsize.height < isize.height)
       isize.height = fsize.height;
@@ -219,7 +196,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
       case mforms::BottomLeft:
       case mforms::BottomCenter:
       case mforms::BottomRight:
-        if (![self isFlipped])
+        if (!self.flipped)
           y = 0;
         else
           y = fsize.height - isize.height;
@@ -232,7 +209,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
       case mforms::TopLeft:
       case mforms::TopCenter:
       case mforms::TopRight:
-        if ([self isFlipped])
+        if (self.flipped)
           y = 0;
         else
           y = fsize.height - isize.height;
@@ -244,7 +221,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
 
     [mBackImage drawInRect: NSMakeRect(x, y, isize.width, isize.height)
                   fromRect: NSZeroRect
-                 operation: NSCompositeSourceOver
+                 operation: NSCompositingOperationSourceOver
                   fraction: 1.0
             respectFlipped: YES
                      hints: nil];
@@ -255,7 +232,7 @@ STANDARD_MOUSE_HANDLING(self) // Add handling for mouse events.
 
 - (void)setBackgroundImage: (NSString*) path withAlignment: (mforms::Alignment) align
 {
-  std::string full_path= mforms::App::get()->get_resource_path([path UTF8String]);
+  std::string full_path= mforms::App::get()->get_resource_path(path.UTF8String);
   if (!full_path.empty())
   {
     mBackImage = [[NSImage alloc] initWithContentsOfFile:wrap_nsstring(full_path)];
