@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -396,6 +396,12 @@
 
 //----------------------------------------------------------------------------------------------------------------------
 
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityWindowRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
 static bool popup_create(mforms::Popup *self, mforms::PopupStyle style) {
   return [[MFPopupImpl alloc] initWithObject: self style: style] != nil;
 }
