@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
@@ -26,7 +26,7 @@
 #import "MFView.h"
 #import "MFMForms.h"
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @interface PopupStyleSelector : NSPopUpButton {
   mforms::Selector *mOwner;
@@ -34,6 +34,8 @@
 
 @end
 
+//----------------------------------------------------------------------------------------------------------------------
+
 @implementation PopupStyleSelector
 
 - (instancetype) initWithObject: (::mforms::Selector*) aSelector
@@ -50,39 +52,54 @@
   return self;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
 STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder status.
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (NSSize) minimumSize
 {
   return self.cell.cellSize;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (BOOL) heightIsFixed
 {
   return YES;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void) selectionChanged: (id)sender
 {
   mOwner->callback();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (::mforms::SelectorStyle) selectorStyle
 {
   return ::mforms::SelectorPopup;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityPopUpButtonRole;
+}
+
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSString *)accessibilityValue {
+    std::string value = mOwner->get_string_value();
+    return [NSString stringWithUTF8String: value.c_str()];
+}
+
 @end
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @interface ComboStyleSelector : NSComboBox <NSComboBoxDelegate>
 {
@@ -91,6 +108,8 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 
 @end
 
+//----------------------------------------------------------------------------------------------------------------------
+
 @implementation ComboStyleSelector
 
 - (instancetype) initWithObject: (::mforms::Selector*) aSelector
@@ -110,44 +129,50 @@ STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder sta
 
 STANDARD_FOCUS_HANDLING(self) // Notify backend when getting first responder status.
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (NSSize) minimumSize
 {
   return self.cell.cellSize;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (BOOL) heightIsFixed
 {
   return YES;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void) controlTextDidChange:(NSNotification *)obj
 {
   mOwner->callback();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (void) selectionChanged: (id)sender
 {
   mOwner->callback();
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 - (::mforms::SelectorStyle) selectorStyle
 {
   return ::mforms::SelectorCombobox;
 }
 
+//----------------------------------------------------------------------------------------------------------------------
+
+- (NSAccessibilityRole)accessibilityRole {
+  return NSAccessibilityComboBoxRole;
+}
+
 @end
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 @implementation MFSelectorImpl
 
@@ -162,7 +187,7 @@ static bool selector_create(::mforms::Selector *self, ::mforms::SelectorStyle st
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static void selector_clear(::mforms::Selector *self)
 {
@@ -173,7 +198,7 @@ static void selector_clear(::mforms::Selector *self)
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static int selector_add_item(::mforms::Selector *self, const std::string &item)
 {
@@ -199,7 +224,7 @@ static int selector_add_item(::mforms::Selector *self, const std::string &item)
   return -1;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static void selector_add_items(::mforms::Selector *self, const std::list<std::string> &items)
 {
@@ -210,7 +235,7 @@ static void selector_add_items(::mforms::Selector *self, const std::list<std::st
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static std::string selector_get_item(::mforms::Selector *self, int index)
 {
@@ -238,7 +263,7 @@ static std::string selector_get_item(::mforms::Selector *self, int index)
   return "";
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static std::string selector_get_text(::mforms::Selector *self)
 {
@@ -260,7 +285,7 @@ static std::string selector_get_text(::mforms::Selector *self)
   return "";
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static void selector_set_index(::mforms::Selector *self, int index)
 {
@@ -274,7 +299,7 @@ static void selector_set_index(::mforms::Selector *self, int index)
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static int selector_get_index(::mforms::Selector *self)
 {
@@ -286,7 +311,7 @@ static int selector_get_index(::mforms::Selector *self)
   return -1;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static int selector_get_item_count(::mforms::Selector *self)
 {
@@ -298,7 +323,7 @@ static int selector_get_item_count(::mforms::Selector *self)
   return 0;
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 static void selector_set_value(::mforms::Selector *self, const std::string &value)
 {
@@ -309,7 +334,7 @@ static void selector_set_value(::mforms::Selector *self, const std::string &valu
   }
 }
 
-//--------------------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 void cf_selector_init()
 {
@@ -327,8 +352,6 @@ void cf_selector_init()
   f->_selector_impl.set_value= &selector_set_value;
 }
 
-
 @end
 
 //--------------------------------------------------------------------------------------------------
-
