@@ -1,20 +1,24 @@
 /*
- * Copyright (c) 2011, 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; version 2 of the
- * License.
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License, version 2.0,
+ * as published by the Free Software Foundation.
  *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
+ * documentation.  The authors of MySQL hereby grant you an additional
+ * permission to link the program and your derivative works with the
+ * separately licensed software that they have included with MySQL.
+ * This program is distributed in the hope that it will be useful,  but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+ * the GNU General Public License, version 2.0, for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301  USA
+ * along with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA 
  */
 
 #include "mforms/mforms.h"
@@ -37,7 +41,7 @@ ToolBar::~ToolBar() {
 
 ToolBarItem *ToolBar::find_item(const std::string &name) {
   for (std::vector<ToolBarItem *>::iterator iter = _items.begin(); iter != _items.end(); ++iter)
-    if ((*iter)->get_name() == name)
+    if ((*iter)->getInternalName() == name)
       return *iter;
   return 0;
 }
@@ -109,8 +113,7 @@ void ToolBar::remove_item(ToolBarItem *item) {
   }
 }
 
-ToolBarItem::ToolBarItem(ToolBarItemType type, const bool expandable)
-  : _type(type), _updating(false), _expandable(expandable) {
+ToolBarItem::ToolBarItem(ToolBarItemType type) : _type(type), _updating(false) {
   _impl = &mforms::ControlFactory::get_instance()->_tool_bar_impl;
   _impl->create_tool_item(this, type);
 }
@@ -158,7 +161,6 @@ bool ToolBarItem::get_checked() {
 }
 
 void ToolBarItem::set_name(const std::string &name) {
-  _name = name;
   if (_impl->set_item_name)
     _impl->set_item_name(this, name);
 }
@@ -174,7 +176,7 @@ void ToolBarItem::callback() {
     if (!_updating)
       _clicked_signal(this);
   } catch (std::exception &exc) {
-    logError("Unhandled exception in toolbar callback for %s: %s\n", _name.c_str(), exc.what());
+    logError("Unhandled exception in toolbar callback for %s: %s\n", _internalName.c_str(), exc.what());
     mforms::Utilities::show_error("Unhandled Exception", exc.what(), "OK");
   }
 }
